@@ -35,7 +35,7 @@ DEFINITION = {
     ],
     'database_toolkit': [
         ('sqlalchemy.orm.session', 'instrument_sqlalchemy'),
-        # ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
+        ('sqlalchemy.engine.default', 'instrument_sqlalchemy_engine'),
     ],
     'application_wsgi': [
         ('', ''),
